package forestry.api.apiculture;

/**
 * Enum representing the order of chromosomes in a bee's genome and what they control.
 * 
 * @author SirSengir
 */
public enum EnumBeeChromosome {
	/**
	 * Species of the bee. Alleles here must implement {@link IAlleleBeeSpecies}.
	 */
	SPECIES,
	/**
	 * (Production) Speed of the bee.
	 */
	SPEED,
	/**
	 * Lifespan of the bee.
	 */
	LIFESPAN,
	/**
	 * Fertility of the bee. Determines number of offspring.
	 */
	FERTILITY,
	/**
	 * Temperature difference to its native supported one the bee can tolerate.
	 */
	TEMPERATURE_TOLERANCE,
	/**
	 * Slightly incorrectly named. If true, a naturally dirunal bee can work during the night. If true, a naturally nocturnal bee can work during the day.
	 */
	NOCTURNAL,
	/**
	 * Not used / superseded by fixed values for the species. Probably going to be replaced with a boolean for FIRE_RESIST.
	 */
	@Deprecated
	HUMIDITY,
	/**
	 * Humidity difference to its native supported one the bee can tolerate.
	 */
	HUMIDITY_TOLERANCE,
	/**
	 * If true the bee can work during rain.
	 */
	TOLERANT_FLYER,
	/**
	 * If true, the bee can work without a clear view of the sky.
	 */
	CAVE_DWELLING,
	/**
	 * Contains the supported flower provider.
	 */
	FLOWER_PROVIDER,
	/**
	 * Determines pollination speed.
	 */
	FLOWERING,
	/**
	 * Determines the size of the bee's territory.
	 */
	TERRITORY,
	/**
	 * Determines the bee's effect.
	 */
	EFFECT
}
